<?php

/**
 * @file
 * Defines variables and hooks specific to version of Media module.
 */

define('MPX_PATH_ADMIN', 'admin/config/media/theplatform');
define('MPX_PATH_PLAYER', 'admin/content/media/mpxplayer');
define('MPX_PATH_VIDEO', 'admin/content/media/mpxmedia');
define('MPX_PATH_FILE', 'media');

/**
 * Implements hook_media_browser_plugin_info().
 */
function media_theplatform_mpx_media_browser_plugin_info() {
  $plugins = array();
  if (user_access('administer media')) {
    $plugins['theplatform_mpx_mpxmedia'] = array(
      '#weight' => -10,
    );
    $plugins['theplatform_mpx_mpxplayer'] = array(
      '#weight' => -10,
    );
  }
  return $plugins;
}

/**
 * Implements hook_media_browser_plugin_view().
 */
function media_theplatform_mpx_media_browser_plugin_view($plugin_name, $params) {
  $path = drupal_get_path('module', 'media');

  $types = isset($params['types']) ? $params['types'] : array();
  $multiselect = isset($params['multiselect']) ? $params['multiselect'] : FALSE;

  $redirect = array('media/browser', array('query' => array('render' => 'media-popup')));
  switch ($plugin_name) {
    case 'theplatform_mpx_mpxmedia':
      $from_web_form = drupal_get_form('media_theplatform_mpx_form_media_browser', 'videos');
      return array(
        '#title' => t('mpxMedia'),
        'form' => array($from_web_form),
        '#attached' => array(),
      );
    break;
    case 'theplatform_mpx_mpxplayer':
      $from_web_form = drupal_get_form('media_theplatform_mpx_form_media_browser', 'players');
      return array(
        '#title' => t('mpxPlayers'),
        'form' => array($from_web_form),
        '#attached' => array(),
      );
    break;
  }
  return array();
}

/**
 * Implements hook_form_alter().
 */
function media_theplatform_mpx_form_alter(&$form, &$form_state, $form_id) {
  // Check if it's media: single file delete form OR bulk media delete form.
  $media_file_delete_form = ($form['#id'] == 'media-admin' && isset($form['operation']) && $form['operation']['#value'] == 'delete');
  if ($form['#id'] == 'media-multiple-delete-confirm' || $media_file_delete_form) {
    foreach ($form['files'] as $fid) {
      if (isset($fid['#value'])) {
        $file = file_load($fid['#value']);
        if ($file->filemime == 'video/mpx' && media_theplatform_mpx_get_files_by_player_fid($file->fid)) {
          drupal_set_message(t('@filename cannot be deleted because it is referenced by other mpxMedia Files.', array('@filename' => $file->filename)), 'error');
          unset($form['actions']['submit']);
          unset($form['description']);
        }
      }
    }
  }
}